Method: Aws::APIGateway::Types::UpdateMethodRequest#patch_operations

Defined in:
lib/aws-sdk-apigateway/types.rb

#patch_operationsArray<Types::PatchOperation>

A list of update operations to be applied to the specified resource and in the order specified in this list.

Returns:



7766
7767
7768
7769
7770
7771
7772
7773
# File 'lib/aws-sdk-apigateway/types.rb', line 7766

class UpdateMethodRequest < Struct.new(
  :rest_api_id,
  :resource_id,
  :http_method,
  :patch_operations)
  SENSITIVE = []
  include Aws::Structure
end