Class: Aws::APIGateway::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::APIGateway::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-apigateway/client.rb,
sig/client.rbs
Overview
An API client for APIGateway. To construct a client, you need to configure a :region and :credentials.
client = Aws::APIGateway::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateApiKeyResponseSuccess, _CreateAuthorizerResponseSuccess, _CreateBasePathMappingResponseSuccess, _CreateDeploymentResponseSuccess, _CreateDocumentationPartResponseSuccess, _CreateDocumentationVersionResponseSuccess, _CreateDomainNameAccessAssociationResponseSuccess, _CreateDomainNameResponseSuccess, _CreateModelResponseSuccess, _CreateRequestValidatorResponseSuccess, _CreateResourceResponseSuccess, _CreateRestApiResponseSuccess, _CreateStageResponseSuccess, _CreateUsagePlanKeyResponseSuccess, _CreateUsagePlanResponseSuccess, _CreateVpcLinkResponseSuccess, _GenerateClientCertificateResponseSuccess, _GetAccountResponseSuccess, _GetApiKeyResponseSuccess, _GetApiKeysResponseSuccess, _GetAuthorizerResponseSuccess, _GetAuthorizersResponseSuccess, _GetBasePathMappingResponseSuccess, _GetBasePathMappingsResponseSuccess, _GetClientCertificateResponseSuccess, _GetClientCertificatesResponseSuccess, _GetDeploymentResponseSuccess, _GetDeploymentsResponseSuccess, _GetDocumentationPartResponseSuccess, _GetDocumentationPartsResponseSuccess, _GetDocumentationVersionResponseSuccess, _GetDocumentationVersionsResponseSuccess, _GetDomainNameAccessAssociationsResponseSuccess, _GetDomainNameResponseSuccess, _GetDomainNamesResponseSuccess, _GetExportResponseSuccess, _GetGatewayResponseResponseSuccess, _GetGatewayResponsesResponseSuccess, _GetIntegrationResponseResponseSuccess, _GetIntegrationResponseSuccess, _GetMethodResponseResponseSuccess, _GetMethodResponseSuccess, _GetModelResponseSuccess, _GetModelTemplateResponseSuccess, _GetModelsResponseSuccess, _GetRequestValidatorResponseSuccess, _GetRequestValidatorsResponseSuccess, _GetResourceResponseSuccess, _GetResourcesResponseSuccess, _GetRestApiResponseSuccess, _GetRestApisResponseSuccess, _GetSdkResponseSuccess, _GetSdkTypeResponseSuccess, _GetSdkTypesResponseSuccess, _GetStageResponseSuccess, _GetStagesResponseSuccess, _GetTagsResponseSuccess, _GetUsagePlanKeyResponseSuccess, _GetUsagePlanKeysResponseSuccess, _GetUsagePlanResponseSuccess, _GetUsagePlansResponseSuccess, _GetUsageResponseSuccess, _GetVpcLinkResponseSuccess, _GetVpcLinksResponseSuccess, _ImportApiKeysResponseSuccess, _ImportDocumentationPartsResponseSuccess, _ImportRestApiResponseSuccess, _PutGatewayResponseResponseSuccess, _PutIntegrationResponseResponseSuccess, _PutIntegrationResponseSuccess, _PutMethodResponseResponseSuccess, _PutMethodResponseSuccess, _PutRestApiResponseSuccess, _TestInvokeAuthorizerResponseSuccess, _TestInvokeMethodResponseSuccess, _UpdateAccountResponseSuccess, _UpdateApiKeyResponseSuccess, _UpdateAuthorizerResponseSuccess, _UpdateBasePathMappingResponseSuccess, _UpdateClientCertificateResponseSuccess, _UpdateDeploymentResponseSuccess, _UpdateDocumentationPartResponseSuccess, _UpdateDocumentationVersionResponseSuccess, _UpdateDomainNameResponseSuccess, _UpdateGatewayResponseResponseSuccess, _UpdateIntegrationResponseResponseSuccess, _UpdateIntegrationResponseSuccess, _UpdateMethodResponseResponseSuccess, _UpdateMethodResponseSuccess, _UpdateModelResponseSuccess, _UpdateRequestValidatorResponseSuccess, _UpdateResourceResponseSuccess, _UpdateRestApiResponseSuccess, _UpdateStageResponseSuccess, _UpdateUsagePlanResponseSuccess, _UpdateUsageResponseSuccess, _UpdateVpcLinkResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_api_key(params = {}) ⇒ Types::ApiKey
Create an ApiKey resource.
-
#create_authorizer(params = {}) ⇒ Types::Authorizer
Adds a new Authorizer resource to an existing RestApi resource.
-
#create_base_path_mapping(params = {}) ⇒ Types::BasePathMapping
Creates a new BasePathMapping resource.
-
#create_deployment(params = {}) ⇒ Types::Deployment
Creates a Deployment resource, which makes a specified RestApi callable over the internet.
-
#create_documentation_part(params = {}) ⇒ Types::DocumentationPart
Creates a documentation part.
-
#create_documentation_version(params = {}) ⇒ Types::DocumentationVersion
Creates a documentation version.
-
#create_domain_name(params = {}) ⇒ Types::DomainName
Creates a new domain name.
-
#create_domain_name_access_association(params = {}) ⇒ Types::DomainNameAccessAssociation
Creates a domain name access association resource between an access association source and a private custom domain name.
-
#create_model(params = {}) ⇒ Types::Model
Adds a new Model resource to an existing RestApi resource.
-
#create_request_validator(params = {}) ⇒ Types::RequestValidator
Creates a RequestValidator of a given RestApi.
-
#create_resource(params = {}) ⇒ Types::Resource
Creates a Resource resource.
-
#create_rest_api(params = {}) ⇒ Types::RestApi
Creates a new RestApi resource.
-
#create_stage(params = {}) ⇒ Types::Stage
Creates a new Stage resource that references a pre-existing Deployment for the API.
-
#create_usage_plan(params = {}) ⇒ Types::UsagePlan
Creates a usage plan with the throttle and quota limits, as well as the associated API stages, specified in the payload.
-
#create_usage_plan_key(params = {}) ⇒ Types::UsagePlanKey
Creates a usage plan key for adding an existing API key to a usage plan.
-
#create_vpc_link(params = {}) ⇒ Types::VpcLink
Creates a VPC link, under the caller's account in a selected region, in an asynchronous operation that typically takes 2-4 minutes to complete and become operational.
-
#delete_api_key(params = {}) ⇒ Struct
Deletes the ApiKey resource.
-
#delete_authorizer(params = {}) ⇒ Struct
Deletes an existing Authorizer resource.
-
#delete_base_path_mapping(params = {}) ⇒ Struct
Deletes the BasePathMapping resource.
-
#delete_client_certificate(params = {}) ⇒ Struct
Deletes the ClientCertificate resource.
-
#delete_deployment(params = {}) ⇒ Struct
Deletes a Deployment resource.
-
#delete_documentation_part(params = {}) ⇒ Struct
Deletes a documentation part.
-
#delete_documentation_version(params = {}) ⇒ Struct
Deletes a documentation version.
-
#delete_domain_name(params = {}) ⇒ Struct
Deletes the DomainName resource.
-
#delete_domain_name_access_association(params = {}) ⇒ Struct
Deletes the DomainNameAccessAssociation resource.
-
#delete_gateway_response(params = {}) ⇒ Struct
Clears any customization of a GatewayResponse of a specified response type on the given RestApi and resets it with the default settings.
-
#delete_integration(params = {}) ⇒ Struct
Represents a delete integration.
-
#delete_integration_response(params = {}) ⇒ Struct
Represents a delete integration response.
-
#delete_method(params = {}) ⇒ Struct
Deletes an existing Method resource.
-
#delete_method_response(params = {}) ⇒ Struct
Deletes an existing MethodResponse resource.
-
#delete_model(params = {}) ⇒ Struct
Deletes a model.
-
#delete_request_validator(params = {}) ⇒ Struct
Deletes a RequestValidator of a given RestApi.
-
#delete_resource(params = {}) ⇒ Struct
Deletes a Resource resource.
-
#delete_rest_api(params = {}) ⇒ Struct
Deletes the specified API.
-
#delete_stage(params = {}) ⇒ Struct
Deletes a Stage resource.
-
#delete_usage_plan(params = {}) ⇒ Struct
Deletes a usage plan of a given plan Id.
-
#delete_usage_plan_key(params = {}) ⇒ Struct
Deletes a usage plan key and remove the underlying API key from the associated usage plan.
-
#delete_vpc_link(params = {}) ⇒ Struct
Deletes an existing VpcLink of a specified identifier.
-
#flush_stage_authorizers_cache(params = {}) ⇒ Struct
Flushes all authorizer cache entries on a stage.
-
#flush_stage_cache(params = {}) ⇒ Struct
Flushes a stage's cache.
-
#generate_client_certificate(params = {}) ⇒ Types::ClientCertificate
Generates a ClientCertificate resource.
-
#get_account(params = {}) ⇒ Types::Account
Gets information about the current Account resource.
-
#get_api_key(params = {}) ⇒ Types::ApiKey
Gets information about the current ApiKey resource.
-
#get_api_keys(params = {}) ⇒ Types::ApiKeys
Gets information about the current ApiKeys resource.
-
#get_authorizer(params = {}) ⇒ Types::Authorizer
Describe an existing Authorizer resource.
-
#get_authorizers(params = {}) ⇒ Types::Authorizers
Describe an existing Authorizers resource.
-
#get_base_path_mapping(params = {}) ⇒ Types::BasePathMapping
Describe a BasePathMapping resource.
-
#get_base_path_mappings(params = {}) ⇒ Types::BasePathMappings
Represents a collection of BasePathMapping resources.
-
#get_client_certificate(params = {}) ⇒ Types::ClientCertificate
Gets information about the current ClientCertificate resource.
-
#get_client_certificates(params = {}) ⇒ Types::ClientCertificates
Gets a collection of ClientCertificate resources.
-
#get_deployment(params = {}) ⇒ Types::Deployment
Gets information about a Deployment resource.
-
#get_deployments(params = {}) ⇒ Types::Deployments
Gets information about a Deployments collection.
-
#get_documentation_part(params = {}) ⇒ Types::DocumentationPart
Gets a documentation part.
-
#get_documentation_parts(params = {}) ⇒ Types::DocumentationParts
Gets documentation parts.
-
#get_documentation_version(params = {}) ⇒ Types::DocumentationVersion
Gets a documentation version.
-
#get_documentation_versions(params = {}) ⇒ Types::DocumentationVersions
Gets documentation versions.
-
#get_domain_name(params = {}) ⇒ Types::DomainName
Represents a domain name that is contained in a simpler, more intuitive URL that can be called.
-
#get_domain_name_access_associations(params = {}) ⇒ Types::DomainNameAccessAssociations
Represents a collection on DomainNameAccessAssociations resources.
-
#get_domain_names(params = {}) ⇒ Types::DomainNames
Represents a collection of DomainName resources.
-
#get_export(params = {}) ⇒ Types::ExportResponse
Exports a deployed version of a RestApi in a specified format.
-
#get_gateway_response(params = {}) ⇒ Types::GatewayResponse
Gets a GatewayResponse of a specified response type on the given RestApi.
-
#get_gateway_responses(params = {}) ⇒ Types::GatewayResponses
Gets the GatewayResponses collection on the given RestApi.
-
#get_integration(params = {}) ⇒ Types::Integration
Get the integration settings.
-
#get_integration_response(params = {}) ⇒ Types::IntegrationResponse
Represents a get integration response.
-
#get_method(params = {}) ⇒ Types::Method
Describe an existing Method resource.
-
#get_method_response(params = {}) ⇒ Types::MethodResponse
Describes a MethodResponse resource.
-
#get_model(params = {}) ⇒ Types::Model
Describes an existing model defined for a RestApi resource.
-
#get_model_template(params = {}) ⇒ Types::Template
Generates a sample mapping template that can be used to transform a payload into the structure of a model.
-
#get_models(params = {}) ⇒ Types::Models
Describes existing Models defined for a RestApi resource.
-
#get_request_validator(params = {}) ⇒ Types::RequestValidator
Gets a RequestValidator of a given RestApi.
-
#get_request_validators(params = {}) ⇒ Types::RequestValidators
Gets the RequestValidators collection of a given RestApi.
-
#get_resource(params = {}) ⇒ Types::Resource
Lists information about a resource.
-
#get_resources(params = {}) ⇒ Types::Resources
Lists information about a collection of Resource resources.
-
#get_rest_api(params = {}) ⇒ Types::RestApi
Lists the RestApi resource in the collection.
-
#get_rest_apis(params = {}) ⇒ Types::RestApis
Lists the RestApis resources for your collection.
-
#get_sdk(params = {}) ⇒ Types::SdkResponse
Generates a client SDK for a RestApi and Stage.
-
#get_sdk_type(params = {}) ⇒ Types::SdkType
Gets an SDK type.
-
#get_sdk_types(params = {}) ⇒ Types::SdkTypes
Gets SDK types.
-
#get_stage(params = {}) ⇒ Types::Stage
Gets information about a Stage resource.
-
#get_stages(params = {}) ⇒ Types::Stages
Gets information about one or more Stage resources.
-
#get_tags(params = {}) ⇒ Types::Tags
Gets the Tags collection for a given resource.
-
#get_usage(params = {}) ⇒ Types::Usage
Gets the usage data of a usage plan in a specified time interval.
-
#get_usage_plan(params = {}) ⇒ Types::UsagePlan
Gets a usage plan of a given plan identifier.
-
#get_usage_plan_key(params = {}) ⇒ Types::UsagePlanKey
Gets a usage plan key of a given key identifier.
-
#get_usage_plan_keys(params = {}) ⇒ Types::UsagePlanKeys
Gets all the usage plan keys representing the API keys added to a specified usage plan.
-
#get_usage_plans(params = {}) ⇒ Types::UsagePlans
Gets all the usage plans of the caller's account.
-
#get_vpc_link(params = {}) ⇒ Types::VpcLink
Gets a specified VPC link under the caller's account in a region.
-
#get_vpc_links(params = {}) ⇒ Types::VpcLinks
Gets the VpcLinks collection under the caller's account in a selected region.
-
#import_api_keys(params = {}) ⇒ Types::ApiKeyIds
Import API keys from an external source, such as a CSV-formatted file.
-
#import_documentation_parts(params = {}) ⇒ Types::DocumentationPartIds
Imports documentation parts.
-
#import_rest_api(params = {}) ⇒ Types::RestApi
A feature of the API Gateway control service for creating a new API from an external API definition file.
-
#put_gateway_response(params = {}) ⇒ Types::GatewayResponse
Creates a customization of a GatewayResponse of a specified response type and status code on the given RestApi.
-
#put_integration(params = {}) ⇒ Types::Integration
Sets up a method's integration.
-
#put_integration_response(params = {}) ⇒ Types::IntegrationResponse
Represents a put integration.
-
#put_method(params = {}) ⇒ Types::Method
Add a method to an existing Resource resource.
-
#put_method_response(params = {}) ⇒ Types::MethodResponse
Adds a MethodResponse to an existing Method resource.
-
#put_rest_api(params = {}) ⇒ Types::RestApi
A feature of the API Gateway control service for updating an existing API with an input of external API definitions.
-
#reject_domain_name_access_association(params = {}) ⇒ Struct
Rejects a domain name access association with a private custom domain name.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates a tag on a given resource.
-
#test_invoke_authorizer(params = {}) ⇒ Types::TestInvokeAuthorizerResponse
Simulate the execution of an Authorizer in your RestApi with headers, parameters, and an incoming request body.
-
#test_invoke_method(params = {}) ⇒ Types::TestInvokeMethodResponse
Simulate the invocation of a Method in your RestApi with headers, parameters, and an incoming request body.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a given resource.
-
#update_account(params = {}) ⇒ Types::Account
Changes information about the current Account resource.
-
#update_api_key(params = {}) ⇒ Types::ApiKey
Changes information about an ApiKey resource.
-
#update_authorizer(params = {}) ⇒ Types::Authorizer
Updates an existing Authorizer resource.
-
#update_base_path_mapping(params = {}) ⇒ Types::BasePathMapping
Changes information about the BasePathMapping resource.
-
#update_client_certificate(params = {}) ⇒ Types::ClientCertificate
Changes information about an ClientCertificate resource.
-
#update_deployment(params = {}) ⇒ Types::Deployment
Changes information about a Deployment resource.
-
#update_documentation_part(params = {}) ⇒ Types::DocumentationPart
Updates a documentation part.
-
#update_documentation_version(params = {}) ⇒ Types::DocumentationVersion
Updates a documentation version.
-
#update_domain_name(params = {}) ⇒ Types::DomainName
Changes information about the DomainName resource.
-
#update_gateway_response(params = {}) ⇒ Types::GatewayResponse
Updates a GatewayResponse of a specified response type on the given RestApi.
-
#update_integration(params = {}) ⇒ Types::Integration
Represents an update integration.
-
#update_integration_response(params = {}) ⇒ Types::IntegrationResponse
Represents an update integration response.
-
#update_method(params = {}) ⇒ Types::Method
Updates an existing Method resource.
-
#update_method_response(params = {}) ⇒ Types::MethodResponse
Updates an existing MethodResponse resource.
-
#update_model(params = {}) ⇒ Types::Model
Changes information about a model.
-
#update_request_validator(params = {}) ⇒ Types::RequestValidator
Updates a RequestValidator of a given RestApi.
-
#update_resource(params = {}) ⇒ Types::Resource
Changes information about a Resource resource.
-
#update_rest_api(params = {}) ⇒ Types::RestApi
Changes information about the specified API.
-
#update_stage(params = {}) ⇒ Types::Stage
Changes information about a Stage resource.
-
#update_usage(params = {}) ⇒ Types::Usage
Grants a temporary extension to the remaining quota of a usage plan associated with a specified API key.
-
#update_usage_plan(params = {}) ⇒ Types::UsagePlan
Updates a usage plan of a given plan Id.
-
#update_vpc_link(params = {}) ⇒ Types::VpcLink
Updates an existing VpcLink of a specified identifier.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-apigateway/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7524 7525 7526 |
# File 'lib/aws-sdk-apigateway/client.rb', line 7524 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7527 7528 7529 |
# File 'lib/aws-sdk-apigateway/client.rb', line 7527 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 |
# File 'lib/aws-sdk-apigateway/client.rb', line 7497 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::APIGateway') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-apigateway' context[:gem_version] = '1.137.0' Seahorse::Client::Request.new(handlers, context) end |
#create_api_key(params = {}) ⇒ Types::ApiKey
Create an ApiKey resource.
95 |
# File 'sig/client.rbs', line 95
def create_api_key: (
|
#create_authorizer(params = {}) ⇒ Types::Authorizer
Adds a new Authorizer resource to an existing RestApi resource.
126 |
# File 'sig/client.rbs', line 126
def create_authorizer: (
|
#create_base_path_mapping(params = {}) ⇒ Types::BasePathMapping
Creates a new BasePathMapping resource.
147 |
# File 'sig/client.rbs', line 147
def create_base_path_mapping: (
|
#create_deployment(params = {}) ⇒ Types::Deployment
Creates a Deployment resource, which makes a specified RestApi callable over the internet.
164 |
# File 'sig/client.rbs', line 164
def create_deployment: (
|
#create_documentation_part(params = {}) ⇒ Types::DocumentationPart
Creates a documentation part.
188 |
# File 'sig/client.rbs', line 188
def create_documentation_part: (
|
#create_documentation_version(params = {}) ⇒ Types::DocumentationVersion
Creates a documentation version
208 |
# File 'sig/client.rbs', line 208
def create_documentation_version: (
|
#create_domain_name(params = {}) ⇒ Types::DomainName
Creates a new domain name.
243 |
# File 'sig/client.rbs', line 243
def create_domain_name: (
|
#create_domain_name_access_association(params = {}) ⇒ Types::DomainNameAccessAssociation
Creates a domain name access association resource between an access association source and a private custom domain name.
279 |
# File 'sig/client.rbs', line 279
def create_domain_name_access_association: (
|
#create_model(params = {}) ⇒ Types::Model
Adds a new Model resource to an existing RestApi resource.
296 |
# File 'sig/client.rbs', line 296
def create_model: (
|
#create_request_validator(params = {}) ⇒ Types::RequestValidator
Creates a RequestValidator of a given RestApi.
313 |
# File 'sig/client.rbs', line 313
def create_request_validator: (
|
#create_resource(params = {}) ⇒ Types::Resource
Creates a Resource resource.
330 |
# File 'sig/client.rbs', line 330
def create_resource: (
|
#create_rest_api(params = {}) ⇒ Types::RestApi
Creates a new RestApi resource.
359 |
# File 'sig/client.rbs', line 359
def create_rest_api: (
|
#create_stage(params = {}) ⇒ Types::Stage
Creates a new Stage resource that references a pre-existing Deployment for the API.
401 |
# File 'sig/client.rbs', line 401
def create_stage: (
|
#create_usage_plan(params = {}) ⇒ Types::UsagePlan
Creates a usage plan with the throttle and quota limits, as well as the associated API stages, specified in the payload.
433 |
# File 'sig/client.rbs', line 433
def create_usage_plan: (
|
#create_usage_plan_key(params = {}) ⇒ Types::UsagePlanKey
Creates a usage plan key for adding an existing API key to a usage plan.
467 |
# File 'sig/client.rbs', line 467
def create_usage_plan_key: (
|
#create_vpc_link(params = {}) ⇒ Types::VpcLink
Creates a VPC link, under the caller's account in a selected region, in an asynchronous operation that typically takes 2-4 minutes to complete and become operational. The caller must have permissions to create and update VPC Endpoint services.
485 |
# File 'sig/client.rbs', line 485
def create_vpc_link: (
|
#delete_api_key(params = {}) ⇒ Struct
Deletes the ApiKey resource.
494 |
# File 'sig/client.rbs', line 494
def delete_api_key: (
|
#delete_authorizer(params = {}) ⇒ Struct
Deletes an existing Authorizer resource.
500 |
# File 'sig/client.rbs', line 500
def delete_authorizer: (
|
#delete_base_path_mapping(params = {}) ⇒ Struct
Deletes the BasePathMapping resource.
507 |
# File 'sig/client.rbs', line 507
def delete_base_path_mapping: (
|
#delete_client_certificate(params = {}) ⇒ Struct
Deletes the ClientCertificate resource.
515 |
# File 'sig/client.rbs', line 515
def delete_client_certificate: (
|
#delete_deployment(params = {}) ⇒ Struct
Deletes a Deployment resource. Deleting a deployment will only succeed if there are no Stage resources associated with it.
521 |
# File 'sig/client.rbs', line 521
def delete_deployment: (
|
#delete_documentation_part(params = {}) ⇒ Struct
Deletes a documentation part
528 |
# File 'sig/client.rbs', line 528
def delete_documentation_part: (
|
#delete_documentation_version(params = {}) ⇒ Struct
Deletes a documentation version.
535 |
# File 'sig/client.rbs', line 535
def delete_documentation_version: (
|
#delete_domain_name(params = {}) ⇒ Struct
Deletes the DomainName resource.
542 |
# File 'sig/client.rbs', line 542
def delete_domain_name: (
|
#delete_domain_name_access_association(params = {}) ⇒ Struct
Deletes the DomainNameAccessAssociation resource.
Only the AWS account that created the DomainNameAccessAssociation resource can delete it. To stop an access association source in another AWS account from accessing your private custom domain name, use the RejectDomainNameAccessAssociation operation.
549 |
# File 'sig/client.rbs', line 549
def delete_domain_name_access_association: (
|
#delete_gateway_response(params = {}) ⇒ Struct
Clears any customization of a GatewayResponse of a specified response type on the given RestApi and resets it with the default settings.
555 |
# File 'sig/client.rbs', line 555
def delete_gateway_response: (
|
#delete_integration(params = {}) ⇒ Struct
Represents a delete integration.
562 |
# File 'sig/client.rbs', line 562
def delete_integration: (
|
#delete_integration_response(params = {}) ⇒ Struct
Represents a delete integration response.
570 |
# File 'sig/client.rbs', line 570
def delete_integration_response: (
|
#delete_method(params = {}) ⇒ Struct
Deletes an existing Method resource.
579 |
# File 'sig/client.rbs', line 579
def delete_method: (
|
#delete_method_response(params = {}) ⇒ Struct
Deletes an existing MethodResponse resource.
587 |
# File 'sig/client.rbs', line 587
def delete_method_response: (
|
#delete_model(params = {}) ⇒ Struct
Deletes a model.
596 |
# File 'sig/client.rbs', line 596
def delete_model: (
|
#delete_request_validator(params = {}) ⇒ Struct
Deletes a RequestValidator of a given RestApi.
603 |
# File 'sig/client.rbs', line 603
def delete_request_validator: (
|
#delete_resource(params = {}) ⇒ Struct
Deletes a Resource resource.
610 |
# File 'sig/client.rbs', line 610
def delete_resource: (
|
#delete_rest_api(params = {}) ⇒ Struct
Deletes the specified API.
617 |
# File 'sig/client.rbs', line 617
def delete_rest_api: (
|
#delete_stage(params = {}) ⇒ Struct
Deletes a Stage resource.
623 |
# File 'sig/client.rbs', line 623
def delete_stage: (
|
#delete_usage_plan(params = {}) ⇒ Struct
Deletes a usage plan of a given plan Id.
630 |
# File 'sig/client.rbs', line 630
def delete_usage_plan: (
|
#delete_usage_plan_key(params = {}) ⇒ Struct
Deletes a usage plan key and remove the underlying API key from the associated usage plan.
636 |
# File 'sig/client.rbs', line 636
def delete_usage_plan_key: (
|
#delete_vpc_link(params = {}) ⇒ Struct
Deletes an existing VpcLink of a specified identifier.
643 |
# File 'sig/client.rbs', line 643
def delete_vpc_link: (
|
#flush_stage_authorizers_cache(params = {}) ⇒ Struct
Flushes all authorizer cache entries on a stage.
649 |
# File 'sig/client.rbs', line 649
def flush_stage_authorizers_cache: (
|
#flush_stage_cache(params = {}) ⇒ Struct
Flushes a stage's cache.
656 |
# File 'sig/client.rbs', line 656
def flush_stage_cache: (
|
#generate_client_certificate(params = {}) ⇒ Types::ClientCertificate
Generates a ClientCertificate resource.
672 |
# File 'sig/client.rbs', line 672
def generate_client_certificate: (
|
#get_account(params = {}) ⇒ Types::Account
Gets information about the current Account resource.
686 |
# File 'sig/client.rbs', line 686
def get_account: (
|
#get_api_key(params = {}) ⇒ Types::ApiKey
Gets information about the current ApiKey resource.
704 |
# File 'sig/client.rbs', line 704
def get_api_key: (
|
#get_api_keys(params = {}) ⇒ Types::ApiKeys
Gets information about the current ApiKeys resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
717 |
# File 'sig/client.rbs', line 717
def get_api_keys: (
|
#get_authorizer(params = {}) ⇒ Types::Authorizer
Describe an existing Authorizer resource.
740 |
# File 'sig/client.rbs', line 740
def get_authorizer: (
|
#get_authorizers(params = {}) ⇒ Types::Authorizers
Describe an existing Authorizers resource.
752 |
# File 'sig/client.rbs', line 752
def get_authorizers: (
|
#get_base_path_mapping(params = {}) ⇒ Types::BasePathMapping
Describe a BasePathMapping resource.
766 |
# File 'sig/client.rbs', line 766
def get_base_path_mapping: (
|
#get_base_path_mappings(params = {}) ⇒ Types::BasePathMappings
Represents a collection of BasePathMapping resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
779 |
# File 'sig/client.rbs', line 779
def get_base_path_mappings: (
|
#get_client_certificate(params = {}) ⇒ Types::ClientCertificate
Gets information about the current ClientCertificate resource.
797 |
# File 'sig/client.rbs', line 797
def get_client_certificate: (
|
#get_client_certificates(params = {}) ⇒ Types::ClientCertificates
Gets a collection of ClientCertificate resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
808 |
# File 'sig/client.rbs', line 808
def get_client_certificates: (
|
#get_deployment(params = {}) ⇒ Types::Deployment
Gets information about a Deployment resource.
822 |
# File 'sig/client.rbs', line 822
def get_deployment: (
|
#get_deployments(params = {}) ⇒ Types::Deployments
Gets information about a Deployments collection.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
835 |
# File 'sig/client.rbs', line 835
def get_deployments: (
|
#get_documentation_part(params = {}) ⇒ Types::DocumentationPart
Gets a documentation part.
849 |
# File 'sig/client.rbs', line 849
def get_documentation_part: (
|
#get_documentation_parts(params = {}) ⇒ Types::DocumentationParts
Gets documentation parts.
861 |
# File 'sig/client.rbs', line 861
def get_documentation_parts: (
|
#get_documentation_version(params = {}) ⇒ Types::DocumentationVersion
Gets a documentation version.
879 |
# File 'sig/client.rbs', line 879
def get_documentation_version: (
|
#get_documentation_versions(params = {}) ⇒ Types::DocumentationVersions
Gets documentation versions.
891 |
# File 'sig/client.rbs', line 891
def get_documentation_versions: (
|
#get_domain_name(params = {}) ⇒ Types::DomainName
Represents a domain name that is contained in a simpler, more intuitive URL that can be called.
925 |
# File 'sig/client.rbs', line 925
def get_domain_name: (
|
#get_domain_name_access_associations(params = {}) ⇒ Types::DomainNameAccessAssociations
Represents a collection on DomainNameAccessAssociations resources.
937 |
# File 'sig/client.rbs', line 937
def get_domain_name_access_associations: (
|
#get_domain_names(params = {}) ⇒ Types::DomainNames
Represents a collection of DomainName resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
950 |
# File 'sig/client.rbs', line 950
def get_domain_names: (
|
#get_export(params = {}) ⇒ Types::ExportResponse
Exports a deployed version of a RestApi in a specified format.
964 |
# File 'sig/client.rbs', line 964
def get_export: (
|
#get_gateway_response(params = {}) ⇒ Types::GatewayResponse
Gets a GatewayResponse of a specified response type on the given RestApi.
982 |
# File 'sig/client.rbs', line 982
def get_gateway_response: (
|
#get_gateway_responses(params = {}) ⇒ Types::GatewayResponses
Gets the GatewayResponses collection on the given RestApi. If an API developer has not added any definitions for gateway responses, the result will be the API Gateway-generated default GatewayResponses collection for the supported response types.
994 |
# File 'sig/client.rbs', line 994
def get_gateway_responses: (
|
#get_integration(params = {}) ⇒ Types::Integration
Get the integration settings.
1022 |
# File 'sig/client.rbs', line 1022
def get_integration: (
|
#get_integration_response(params = {}) ⇒ Types::IntegrationResponse
Represents a get integration response.
1038 |
# File 'sig/client.rbs', line 1038
def get_integration_response: (
|
#get_method(params = {}) ⇒ Types::Method
Describe an existing Method resource.
1061 |
# File 'sig/client.rbs', line 1061
def get_method: (
|
#get_method_response(params = {}) ⇒ Types::MethodResponse
Describes a MethodResponse resource.
1075 |
# File 'sig/client.rbs', line 1075
def get_method_response: (
|
#get_model(params = {}) ⇒ Types::Model
Describes an existing model defined for a RestApi resource.
1092 |
# File 'sig/client.rbs', line 1092
def get_model: (
|
#get_model_template(params = {}) ⇒ Types::Template
Generates a sample mapping template that can be used to transform a payload into the structure of a model.
1104 |
# File 'sig/client.rbs', line 1104
def get_model_template: (
|
#get_models(params = {}) ⇒ Types::Models
Describes existing Models defined for a RestApi resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1116 |
# File 'sig/client.rbs', line 1116
def get_models: (
|
#get_request_validator(params = {}) ⇒ Types::RequestValidator
Gets a RequestValidator of a given RestApi.
1131 |
# File 'sig/client.rbs', line 1131
def get_request_validator: (
|
#get_request_validators(params = {}) ⇒ Types::RequestValidators
Gets the RequestValidators collection of a given RestApi.
1143 |
# File 'sig/client.rbs', line 1143
def get_request_validators: (
|
#get_resource(params = {}) ⇒ Types::Resource
Lists information about a resource.
1159 |
# File 'sig/client.rbs', line 1159
def get_resource: (
|
#get_resources(params = {}) ⇒ Types::Resources
Lists information about a collection of Resource resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1172 |
# File 'sig/client.rbs', line 1172
def get_resources: (
|
#get_rest_api(params = {}) ⇒ Types::RestApi
Lists the RestApi resource in the collection.
1202 |
# File 'sig/client.rbs', line 1202
def get_rest_api: (
|
#get_rest_apis(params = {}) ⇒ Types::RestApis
Lists the RestApis resources for your collection.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1213 |
# File 'sig/client.rbs', line 1213
def get_rest_apis: (
|
#get_sdk(params = {}) ⇒ Types::SdkResponse
Generates a client SDK for a RestApi and Stage.
1226 |
# File 'sig/client.rbs', line 1226
def get_sdk: (
|
#get_sdk_type(params = {}) ⇒ Types::SdkType
Gets an SDK type.
1242 |
# File 'sig/client.rbs', line 1242
def get_sdk_type: (
|
#get_sdk_types(params = {}) ⇒ Types::SdkTypes
Gets SDK types
1253 |
# File 'sig/client.rbs', line 1253
def get_sdk_types: (
|
#get_stage(params = {}) ⇒ Types::Stage
Gets information about a Stage resource.
1280 |
# File 'sig/client.rbs', line 1280
def get_stage: (
|
#get_stages(params = {}) ⇒ Types::Stages
Gets information about one or more Stage resources.
1291 |
# File 'sig/client.rbs', line 1291
def get_stages: (
|
#get_tags(params = {}) ⇒ Types::Tags
Gets the Tags collection for a given resource.
1302 |
# File 'sig/client.rbs', line 1302
def get_tags: (
|
#get_usage(params = {}) ⇒ Types::Usage
Gets the usage data of a usage plan in a specified time interval.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1318 |
# File 'sig/client.rbs', line 1318
def get_usage: (
|
#get_usage_plan(params = {}) ⇒ Types::UsagePlan
Gets a usage plan of a given plan identifier.
1340 |
# File 'sig/client.rbs', line 1340
def get_usage_plan: (
|
#get_usage_plan_key(params = {}) ⇒ Types::UsagePlanKey
Gets a usage plan key of a given key identifier.
1353 |
# File 'sig/client.rbs', line 1353
def get_usage_plan_key: (
|
#get_usage_plan_keys(params = {}) ⇒ Types::UsagePlanKeys
Gets all the usage plan keys representing the API keys added to a specified usage plan.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1365 |
# File 'sig/client.rbs', line 1365
def get_usage_plan_keys: (
|
#get_usage_plans(params = {}) ⇒ Types::UsagePlans
Gets all the usage plans of the caller's account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1379 |
# File 'sig/client.rbs', line 1379
def get_usage_plans: (
|
#get_vpc_link(params = {}) ⇒ Types::VpcLink
Gets a specified VPC link under the caller's account in a region.
1397 |
# File 'sig/client.rbs', line 1397
def get_vpc_link: (
|
#get_vpc_links(params = {}) ⇒ Types::VpcLinks
Gets the VpcLinks collection under the caller's account in a selected region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1408 |
# File 'sig/client.rbs', line 1408
def get_vpc_links: (
|
#import_api_keys(params = {}) ⇒ Types::ApiKeyIds
Import API keys from an external source, such as a CSV-formatted file.
1420 |
# File 'sig/client.rbs', line 1420
def import_api_keys: (
|
#import_documentation_parts(params = {}) ⇒ Types::DocumentationPartIds
Imports documentation parts
1433 |
# File 'sig/client.rbs', line 1433
def import_documentation_parts: (
|
#import_rest_api(params = {}) ⇒ Types::RestApi
A feature of the API Gateway control service for creating a new API from an external API definition file.
1463 |
# File 'sig/client.rbs', line 1463
def import_rest_api: (
|
#put_gateway_response(params = {}) ⇒ Types::GatewayResponse
Creates a customization of a GatewayResponse of a specified response type and status code on the given RestApi.
1479 |
# File 'sig/client.rbs', line 1479
def put_gateway_response: (
|
#put_integration(params = {}) ⇒ Types::Integration
Sets up a method's integration.
1509 |
# File 'sig/client.rbs', line 1509
def put_integration: (
|
#put_integration_response(params = {}) ⇒ Types::IntegrationResponse
Represents a put integration.
1543 |
# File 'sig/client.rbs', line 1543
def put_integration_response: (
|
#put_method(params = {}) ⇒ Types::Method
Add a method to an existing Resource resource.
1570 |
# File 'sig/client.rbs', line 1570
def put_method: (
|
#put_method_response(params = {}) ⇒ Types::MethodResponse
Adds a MethodResponse to an existing Method resource.
1592 |
# File 'sig/client.rbs', line 1592
def put_method_response: (
|
#put_rest_api(params = {}) ⇒ Types::RestApi
A feature of the API Gateway control service for updating an existing API with an input of external API definitions. The update can take the form of merging the supplied definition into the existing API or overwriting the existing API.
1624 |
# File 'sig/client.rbs', line 1624
def put_rest_api: (
|
#reject_domain_name_access_association(params = {}) ⇒ Struct
Rejects a domain name access association with a private custom domain name.
To reject a domain name access association with an access association source in another AWS account, use this operation. To remove a domain name access association with an access association source in your own account, use the DeleteDomainNameAccessAssociation operation.
1634 |
# File 'sig/client.rbs', line 1634
def reject_domain_name_access_association: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or updates a tag on a given resource.
1641 |
# File 'sig/client.rbs', line 1641
def tag_resource: (
|
#test_invoke_authorizer(params = {}) ⇒ Types::TestInvokeAuthorizerResponse
Simulate the execution of an Authorizer in your RestApi with headers, parameters, and an incoming request body.
1658 |
# File 'sig/client.rbs', line 1658
def test_invoke_authorizer: (
|
#test_invoke_method(params = {}) ⇒ Types::TestInvokeMethodResponse
Simulate the invocation of a Method in your RestApi with headers, parameters, and an incoming request body.
1680 |
# File 'sig/client.rbs', line 1680
def test_invoke_method: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a given resource.
1694 |
# File 'sig/client.rbs', line 1694
def untag_resource: (
|
#update_account(params = {}) ⇒ Types::Account
Changes information about the current Account resource.
1708 |
# File 'sig/client.rbs', line 1708
def update_account: (
|
#update_api_key(params = {}) ⇒ Types::ApiKey
Changes information about an ApiKey resource.
1734 |
# File 'sig/client.rbs', line 1734
def update_api_key: (
|
#update_authorizer(params = {}) ⇒ Types::Authorizer
Updates an existing Authorizer resource.
1761 |
# File 'sig/client.rbs', line 1761
def update_authorizer: (
|
#update_base_path_mapping(params = {}) ⇒ Types::BasePathMapping
Changes information about the BasePathMapping resource.
1782 |
# File 'sig/client.rbs', line 1782
def update_base_path_mapping: (
|
#update_client_certificate(params = {}) ⇒ Types::ClientCertificate
Changes information about an ClientCertificate resource.
1807 |
# File 'sig/client.rbs', line 1807
def update_client_certificate: (
|
#update_deployment(params = {}) ⇒ Types::Deployment
Changes information about a Deployment resource.
1828 |
# File 'sig/client.rbs', line 1828
def update_deployment: (
|
#update_documentation_part(params = {}) ⇒ Types::DocumentationPart
Updates a documentation part.
1849 |
# File 'sig/client.rbs', line 1849
def update_documentation_part: (
|
#update_documentation_version(params = {}) ⇒ Types::DocumentationVersion
Updates a documentation version.
1870 |
# File 'sig/client.rbs', line 1870
def update_documentation_version: (
|
#update_domain_name(params = {}) ⇒ Types::DomainName
Changes information about the DomainName resource.
1911 |
# File 'sig/client.rbs', line 1911
def update_domain_name: (
|
#update_gateway_response(params = {}) ⇒ Types::GatewayResponse
Updates a GatewayResponse of a specified response type on the given RestApi.
1934 |
# File 'sig/client.rbs', line 1934
def update_gateway_response: (
|
#update_integration(params = {}) ⇒ Types::Integration
Represents an update integration.
1969 |
# File 'sig/client.rbs', line 1969
def update_integration: (
|
#update_integration_response(params = {}) ⇒ Types::IntegrationResponse
Represents an update integration response.
1993 |
# File 'sig/client.rbs', line 1993
def update_integration_response: (
|
#update_method(params = {}) ⇒ Types::Method
Updates an existing Method resource.
2024 |
# File 'sig/client.rbs', line 2024
def update_method: (
|
#update_method_response(params = {}) ⇒ Types::MethodResponse
Updates an existing MethodResponse resource.
2046 |
# File 'sig/client.rbs', line 2046
def update_method_response: (
|
#update_model(params = {}) ⇒ Types::Model
Changes information about a model. The maximum size of the model is 400 KB.
2071 |
# File 'sig/client.rbs', line 2071
def update_model: (
|
#update_request_validator(params = {}) ⇒ Types::RequestValidator
Updates a RequestValidator of a given RestApi.
2093 |
# File 'sig/client.rbs', line 2093
def update_request_validator: (
|
#update_resource(params = {}) ⇒ Types::Resource
Changes information about a Resource resource.
2116 |
# File 'sig/client.rbs', line 2116
def update_resource: (
|
#update_rest_api(params = {}) ⇒ Types::RestApi
Changes information about the specified API.
2152 |
# File 'sig/client.rbs', line 2152
def update_rest_api: (
|
#update_stage(params = {}) ⇒ Types::Stage
Changes information about a Stage resource.
2186 |
# File 'sig/client.rbs', line 2186
def update_stage: (
|
#update_usage(params = {}) ⇒ Types::Usage
Grants a temporary extension to the remaining quota of a usage plan associated with a specified API key.
2209 |
# File 'sig/client.rbs', line 2209
def update_usage: (
|
#update_usage_plan(params = {}) ⇒ Types::UsagePlan
Updates a usage plan of a given plan Id.
2235 |
# File 'sig/client.rbs', line 2235
def update_usage_plan: (
|
#update_vpc_link(params = {}) ⇒ Types::VpcLink
Updates an existing VpcLink of a specified identifier.
2259 |
# File 'sig/client.rbs', line 2259
def update_vpc_link: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7517 7518 7519 |
# File 'lib/aws-sdk-apigateway/client.rb', line 7517 def waiter_names [] end |