Class: Aws::APIGateway::Types::ImportDocumentationPartsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::APIGateway::Types::ImportDocumentationPartsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-apigateway/types.rb
Overview
Import documentation parts from an external (e.g., OpenAPI) definition file.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#body ⇒ String
Raw byte array representing the to-be-imported documentation parts.
-
#fail_on_warnings ⇒ Boolean
A query parameter to specify whether to rollback the documentation importation (
true) or not (false) when a warning is encountered. -
#mode ⇒ String
A query parameter to indicate whether to overwrite (
overwrite) any existing DocumentationParts definition or to merge (merge) the new definition into the existing one. -
#rest_api_id ⇒ String
The string identifier of the associated RestApi.
Instance Attribute Details
#body ⇒ String
Raw byte array representing the to-be-imported documentation parts. To import from an OpenAPI file, this is a JSON object.
3449 3450 3451 3452 3453 3454 3455 3456 |
# File 'lib/aws-sdk-apigateway/types.rb', line 3449 class ImportDocumentationPartsRequest < Struct.new( :rest_api_id, :mode, :fail_on_warnings, :body) SENSITIVE = [] include Aws::Structure end |
#fail_on_warnings ⇒ Boolean
A query parameter to specify whether to rollback the documentation
importation (true) or not (false) when a warning is encountered.
The default value is false.
3449 3450 3451 3452 3453 3454 3455 3456 |
# File 'lib/aws-sdk-apigateway/types.rb', line 3449 class ImportDocumentationPartsRequest < Struct.new( :rest_api_id, :mode, :fail_on_warnings, :body) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
A query parameter to indicate whether to overwrite (overwrite) any
existing DocumentationParts definition or to merge (merge) the new
definition into the existing one. The default value is merge.
3449 3450 3451 3452 3453 3454 3455 3456 |
# File 'lib/aws-sdk-apigateway/types.rb', line 3449 class ImportDocumentationPartsRequest < Struct.new( :rest_api_id, :mode, :fail_on_warnings, :body) SENSITIVE = [] include Aws::Structure end |
#rest_api_id ⇒ String
The string identifier of the associated RestApi.
3449 3450 3451 3452 3453 3454 3455 3456 |
# File 'lib/aws-sdk-apigateway/types.rb', line 3449 class ImportDocumentationPartsRequest < Struct.new( :rest_api_id, :mode, :fail_on_warnings, :body) SENSITIVE = [] include Aws::Structure end |