Method: Aws::APIGateway::Types::UpdateBasePathMappingRequest#patch_operations
- Defined in:
- lib/aws-sdk-apigateway/types.rb
#patch_operations ⇒ Array<Types::PatchOperation>
A list of update operations to be applied to the specified resource and in the order specified in this list.
6696 6697 6698 6699 6700 6701 |
# File 'lib/aws-sdk-apigateway/types.rb', line 6696 class UpdateBasePathMappingRequest < Struct.new( :domain_name, :base_path, :patch_operations) include Aws::Structure end |